Documentation
¶
Index ¶
Constants ¶
const ( AdminService = "adminService" WorkflowService = "workflowService" ReplicationStreams = "replicationStreams" ShardManager = "shardManager" ShardRouting = "shardRouting" )
Variables ¶
var Module = fx.Provide( NewLoggerProvider, )
Functions ¶
This section is empty.
Types ¶
type LogComponentName ¶
type LogComponentName string
type LoggerProvider ¶
type LoggerProvider interface {
// Get returns a logger for the given component. If there is no custom config, the root logger will be returned.
Get(component LogComponentName) log.Logger
// With returns a new logger provider with the given tags added to all loggers.
With(tags ...tag.Tag) LoggerProvider
}
LoggerProvider provides customized loggers for different components. Based on the component name, different throttling levels can be applied. Right now, any tags stored with the LoggerProvider with With() will be applied to all loggers returned by Get().
func NewLoggerProvider ¶
func NewLoggerProvider(root log.Logger, config config.ConfigProvider) LoggerProvider
Click to show internal directories.
Click to hide internal directories.